==> nextcloud-30.0.14.tgz: nextcloud/apps/serverinfo/l10n/ug.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU ئۇچۇرى يوق",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: ئومۇمىي: {memTotalBytes} / ھازىرقى ئىشلىتىلىشى: {memUsageBytes}",
    "RAM info not available" : "RAM ئۇچۇرى يوق",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: ئومۇمىي: {swapTotalBytes} / ھازىرقى ئىشلىتىلىشى: {swapUsageBytes}",
    "SWAP info not available" : "SWAP ئۇچۇرى يوق",
    "Copied!" : "كۆچۈرۈلدى!",
    "Not supported!" : "قوللىمايدۇ!",
    "Press ⌘-C to copy." : "كۆچۈرۈش ئۈچۈن ⌘-C نى بېسىڭ.",
    "Press Ctrl-C to copy." : "كۆچۈرۈش ئۈچۈن Ctrl-C نى بېسىڭ.",
    "System" : "سىستېما",
    "Monitoring" : "نازارەت قىلىش",
    "Monitoring app with useful server information" : "پايدىلىق مۇلازىمېتىر ئۇچۇرلىرى بىلەن نازارەت قىلىش دېتالى",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU يۈكى ، RAM ئىشلىتىش ، دىسكا ئىشلىتىش ، ئىشلەتكۈچى سانى قاتارلىق پايدىلىق مۇلازىمېتىر ئۇچۇرلىرى بىلەن تەمىنلەيدۇ.",
    "Operating System:" : "مەشغۇلات سىستېمىسى:",
    "CPU:" : "CPU:",
    "Memory:" : "ئەستە ساقلاش:",
    "Server time:" : "مۇلازىمېتىر ۋاقتى:",
    "Uptime:" : "Uptime:",
    "Temperature" : "تېمپېراتۇرا",
    "Load" : "Load",
    "Memory" : "ئەستە ساقلاش",
    "Disk" : "دىسكا",
    "Mount:" : "تاغ:",
    "Filesystem:" : "ھۆججەت سىستېمىسى:",
    "Size:" : "چوڭلۇقى:",
    "Available:" : "ئىشلەتكىلى بولىدۇ:",
    "Used:" : "ئىشلىتىلگەن:",
    "Files:" : "ھۆججەتلەر:",
    "Storages:" : "دۇكانلار:",
    "Free Space:" : "ھەقسىز بوشلۇق:",
    "Network" : "تور",
    "Hostname:" : "ساھىبجامال:",
    "Gateway:" : "دەرۋازا:",
    "Status:" : "ھالىتى:",
    "Speed:" : "سۈرئەت:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "ئاكتىپ ئىشلەتكۈچىلەر",
    "Last hour" : "ئالدىنقى سائەت",
    "%s%% of all users" : "بارلىق ئىشلەتكۈچىلەرنىڭ% s %%",
    "Last 24 Hours" : "ئاخىرقى 24 سائەت",
    "Last 7 Days" : "ئاخىرقى 7 كۈن",
    "Last 30 Days" : "ئاخىرقى 30 كۈن",
    "Shares" : "Shares",
    "Users:" : "ئىشلەتكۈچىلەر:",
    "Groups:" : "گۇرۇپپىلار:",
    "Links:" : "ئۇلىنىشلار:",
    "Emails:" : "ئېلخەت:",
    "Federated sent:" : "فېدېراتسىيە ئەۋەتىلگەن:",
    "Federated received:" : "فېدېراتسىيە قوبۇل قىلدى:",
    "Talk conversations:" : "سۆھبەت پاراڭلىرى:",
    "PHP" : "PHP",
    "Version:" : "نەشرى:",
    "Memory limit:" : "ئەستە ساقلاش چېكى:",
    "Max execution time:" : "ئىجرا قىلىنىش ۋاقتى:",
    "Upload max size:" : "ئەڭ چوڭ چوڭلۇقى:",
    "OPcache Revalidate Frequency:" : "OPcache چاستوتىنى ئىناۋەتسىز قىلىدۇ:",
    "Extensions:" : "كېڭەيتىلمىسى:",
    "Unable to list extensions" : "كېڭەيتىلمىنى تىزىشقا ئامالسىز",
    "Show phpinfo" : "Phpinfo نى كۆرسەت",
    "Database" : "ساندان",
    "Type:" : "تىپى:",
    "External monitoring tool" : "تاشقى كۆزىتىش قورالى",
    "Use this end point to connect an external monitoring tool:" : "بۇ ئاخىرقى نۇقتىنى ئىشلىتىپ سىرتقى نازارەت قىلىش قورالىنى ئۇلاڭ:",
    "Copy" : "كۆچۈرۈڭ",
    "Output in JSON" : "JSON دىكى چىقىرىش",
    "Skip apps section (including apps section will send an external request to the app store)" : "ئەپ بۆلەكلىرىدىن ئاتلاش (ئەپ بۆلىكىنى ئۆز ئىچىگە ئالىدۇ) ئەپ دۇكىنىغا تاشقى تەلەپ ئەۋەتىدۇ)",
    "Skip server update" : "مۇلازىمېتىر يېڭىلاشتىن ئاتلاڭ",
    "To use an access token, please generate one then set it using the following command:" : "زىيارەت بەلگىسىنى ئىشلىتىش ئۈچۈن بىرنى ھاسىل قىلىڭ ، ئاندىن تۆۋەندىكى بۇيرۇقنى ئىشلىتىپ تەڭشەڭ:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "ئاندىن يۇقارقى URL نى سورىغاندا «NC-Token» ماۋزۇسى ئارقىلىق بەلگە يوللاڭ.",
    "Unknown Processor" : "نامەلۇم بىر تەرەپ قىلغۇچ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.13.tgz: nextcloud/apps/serverinfo/l10n/ug.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU ئۇچۇرى يوق",
    "CPU Usage:" : "CPU ئىشلىتىشچانلىقى:",
    "Load average: {percentage} % ({load}) last minute" : "ئوتتۇرىچە يۈك: ئاخىرقى مىنۇتتا %{percentage}({load}) ",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) ئاخىرقى مىنۇتتا\n{last5MinutesPercentage} % ({last5Minutes}) ئاخىرقى 5 مىنۇتتا\n{last15MinutesPercentage} % ({last15Minutes}) ئاخىرقى 15 مىنۇتتا",
    "RAM Usage:" : "RAM ئىشلىتىشچانلىقى:",
    "SWAP Usage:" : "SWAP ئىشلىتىشچانلىقى:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: ئومۇمىي: {memTotalBytes} / ھازىرقى ئىشلىتىلىشى: {memUsageBytes}",
    "RAM info not available" : "RAM ئۇچۇرى يوق",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: ئومۇمىي: {swapTotalBytes} / ھازىرقى ئىشلىتىلىشى: {swapUsageBytes}",
    "SWAP info not available" : "SWAP ئۇچۇرى يوق",
    "Copied!" : "كۆچۈرۈلدى!",
    "Not supported!" : "قوللىمايدۇ!",
    "Press ⌘-C to copy." : "كۆچۈرۈش ئۈچۈن ⌘-C نى بېسىڭ.",
    "Press Ctrl-C to copy." : "كۆچۈرۈش ئۈچۈن Ctrl-C نى بېسىڭ.",
    "Unknown" : "نامەلۇم",
    "System" : "سىستېما",
    "Monitoring" : "نازارەت قىلىش",
    "Monitoring app with useful server information" : "پايدىلىق مۇلازىمېتىر ئۇچۇرلىرى بىلەن نازارەت قىلىش دېتالى",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU يۈكى ، RAM ئىشلىتىش ، دىسكا ئىشلىتىش ، ئىشلەتكۈچى سانى قاتارلىق پايدىلىق مۇلازىمېتىر ئۇچۇرلىرى بىلەن تەمىنلەيدۇ.",
    "Operating System:" : "مەشغۇلات سىستېمىسى:",
    "CPU:" : "CPU:",
    "threads" : "يىپلار",
    "Memory:" : "ئەستە ساقلاش:",
    "Server time:" : "مۇلازىمېتىر ۋاقتى:",
    "Uptime:" : "ئىشلەش ۋاقتى:",
    "Temperature" : "تېمپېراتۇرا",
    "Load" : "يۈك",
    "Memory" : "ئەستە ساقلاش",
    "Disk" : "دىسكا",
    "Mount:" : "تاغ:",
    "Filesystem:" : "ھۆججەت سىستېمىسى:",
    "Size:" : "چوڭلۇقى:",
    "Available:" : "ئىشلەتكىلى بولىدۇ:",
    "Used:" : "ئىشلىتىلگەن:",
    "Files:" : "ھۆججەتلەر:",
    "Storages:" : "دۇكانلار:",
    "Free Space:" : "ھەقسىز بوشلۇق:",
    "Network" : "تور",
    "Hostname:" : "ساھىبجامال:",
    "Gateway:" : "دەرۋازا:",
    "Status:" : "ھالىتى:",
    "Speed:" : "سۈرئەت:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "ئاكتىپ ئىشلەتكۈچىلەر",
    "Last hour" : "ئالدىنقى سائەت",
    "%s%% of all users" : "بارلىق ئىشلەتكۈچىلەرنىڭ %%%s ",
    "Last 24 Hours" : "ئاخىرقى 24 سائەت",
    "Last 7 Days" : "ئاخىرقى 7 كۈن",
    "Last 30 Days" : "ئاخىرقى 30 كۈن",
    "Shares" : "ھەمبەھىرلەر",
    "Users:" : "ئىشلەتكۈچىلەر:",
    "Groups:" : "گۇرۇپپىلار:",
    "Links:" : "ئۇلىنىشلار:",
    "Emails:" : "ئېلخەت:",
    "Federated sent:" : "فېدېراتسىيە ئەۋەتىلگەن:",
    "Federated received:" : "فېدېراتسىيە قوبۇل قىلدى:",
    "Talk conversations:" : "سۆھبەت پاراڭلىرى:",
    "PHP" : "PHP",
    "Version:" : "نەشرى:",
    "Memory limit:" : "ئەستە ساقلاش چېكى:",
    "Max execution time:" : "ئىجرا قىلىنىش ۋاقتى:",
    "seconds" : "سېكۇنت",
    "Upload max size:" : "ئەڭ چوڭ چوڭلۇقى:",
    "OPcache Revalidate Frequency:" : "OPcache چاستوتىنى ئىناۋەتسىز قىلىدۇ:",
    "Extensions:" : "كېڭەيتىلمىسى:",
    "Unable to list extensions" : "كېڭەيتىلمىنى تىزىشقا ئامالسىز",
    "Show phpinfo" : "Phpinfo نى كۆرسەت",
    "FPM worker pool" : "FPM ئىشچى يىغىندىسى",
    "Pool name:" : "يىغىندا نامى:",
    "Pool type:" : "يىغىندا تىپى:",
    "Start time:" : "باشلىنىش ۋاقتى:",
    "Accepted connections:" : "قۇبۇللانغان ئۇلىنىشلار:",
    "Total processes:" : "جەمئىي جەريانلار:",
    "Active processes:" : "ئاكتىپ جەريانلار:",
    "Idle processes:" : "بىكار جەريانلار:",
    "Listen queue:" : "ئاڭلاش ئۆچرېتى:",
    "Slow requests:" : "ئاستا تەلەپلەر:",
    "Max listen queue:" : "ئەڭ چوڭ ئاڭلاش ئۆچرېتى:",
    "Max active processes:" : "ئەڭ چوڭ ئاكتىپ جەريانلار:",
    "Max children reached:" : "ئەڭ چوڭ تارماقلارغا يەتكىنى:",
    "Database" : "ساندان",
    "Type:" : "تىپى:",
    "External monitoring tool" : "تاشقى كۆزىتىش قورالى",
    "Use this end point to connect an external monitoring tool:" : "بۇ ئاخىرقى نۇقتىنى ئىشلىتىپ سىرتقى نازارەت قىلىش قورالىنى ئۇلاڭ:",
    "Copy" : "كۆچۈرۈڭ",
    "Output in JSON" : "JSON دىكى چىقىرىش",
    "Skip apps section (including apps section will send an external request to the app store)" : "ئەپ بۆلەكلىرىدىن ئاتلاش (ئەپ بۆلىكىنى ئۆز ئىچىگە ئالىدۇ) ئەپ دۇكىنىغا تاشقى تەلەپ ئەۋەتىدۇ)",
    "Skip server update" : "مۇلازىمېتىر يېڭىلاشتىن ئاتلاڭ",
    "To use an access token, please generate one then set it using the following command:" : "زىيارەت بەلگىسىنى ئىشلىتىش ئۈچۈن بىرنى ھاسىل قىلىڭ ، ئاندىن تۆۋەندىكى بۇيرۇقنى ئىشلىتىپ تەڭشەڭ:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "ئاندىن يۇقارقى URL نى سورىغاندا «NC-Token» ماۋزۇسى ئارقىلىق بەلگە يوللاڭ.",
    "Unknown Processor" : "نامەلۇم بىر تەرەپ قىلغۇچ"
},
"nplurals=2; plural=(n != 1);");
